@@ -54,7 +54,8 @@ elif [[ ${abbr} == 'pip' ]]; then  # pip install package
 
     msg="\nDo you want to pip install ${pkg}"
     if [[ ! -z ${_MLHUB_OPTION_YES} ]] || _is_yes "${msg}"; then
-      ${pip} install --root ${package_path}/.python ${pkg}
+      opts="--user --disable-pip-version-check --no-warn-script-location"
+      ${pip} install ${opts} --root ${package_path}/.python ${pkg}
       _check_returncode
     fi
 
